@@ -18,9 +18,6 @@ if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
-
-import sys
-
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -83,6 +80,7 @@ __all__ = (
     "ReplicaGlobalSecondaryIndexTypeDef",
     "ReplicaSettingsDescriptionTypeDef",
     "ReplicaTypeDef",
+    "ResponseMetadata",
     "RestoreSummaryTypeDef",
     "SSEDescriptionTypeDef",
     "SourceTableDetailsTypeDef",
@@ -894,7 +892,9 @@ ReplicaAutoScalingDescriptionTypeDef = TypedDict(
         "GlobalSecondaryIndexes": List["ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef"],
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ReplicaProvisionedWriteCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
-        "ReplicaStatus": Literal["CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE"],
+        "ReplicaStatus": Literal[
+            "CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE", "REGION_DISABLED"
+        ],
     },
     total=False,
 )
@@ -903,12 +903,15 @@ ReplicaDescriptionTypeDef = TypedDict(
     "ReplicaDescriptionTypeDef",
     {
         "RegionName": str,
-        "ReplicaStatus": Literal["CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE"],
+        "ReplicaStatus": Literal[
+            "CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE", "REGION_DISABLED"
+        ],
         "ReplicaStatusDescription": str,
         "ReplicaStatusPercentProgress": str,
         "KMSMasterKeyId": str,
         "ProvisionedThroughputOverride": "ProvisionedThroughputOverrideTypeDef",
         "GlobalSecondaryIndexes": List["ReplicaGlobalSecondaryIndexDescriptionTypeDef"],
+        "ReplicaInaccessibleDateTime": datetime,
     },
     total=False,
 )
@@ -1004,7 +1007,9 @@ _RequiredReplicaSettingsDescriptionTypeDef = TypedDict(
 _OptionalReplicaSettingsDescriptionTypeDef = TypedDict(
     "_OptionalReplicaSettingsDescriptionTypeDef",
     {
-        "ReplicaStatus": Literal["CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE"],
+        "ReplicaStatus": Literal[
+            "CREATING", "CREATION_FAILED", "UPDATING", "DELETING", "ACTIVE", "REGION_DISABLED"
+        ],
         "ReplicaBillingModeSummary": "BillingModeSummaryTypeDef",
         "ReplicaProvisionedReadCapacityUnits": int,
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
@@ -1026,6 +1031,17 @@ class ReplicaSettingsDescriptionTypeDef(
 
 ReplicaTypeDef = TypedDict("ReplicaTypeDef", {"RegionName": str}, total=False)
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredRestoreSummaryTypeDef = TypedDict(
     "_RequiredRestoreSummaryTypeDef", {"RestoreDateTime": datetime, "RestoreInProgress": bool}
 )
@@ -1319,6 +1335,7 @@ BatchGetItemOutputTypeDef = TypedDict(
         ],
         "UnprocessedKeys": Dict[str, "KeysAndAttributesTypeDef"],
         "ConsumedCapacity": List["ConsumedCapacityTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1329,6 +1346,7 @@ BatchWriteItemOutputTypeDef = TypedDict(
         "UnprocessedItems": Dict[str, List["WriteRequestTypeDef"]],
         "ItemCollectionMetrics": Dict[str, List["ItemCollectionMetricsTypeDef"]],
         "ConsumedCapacity": List["ConsumedCapacityTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1384,21 +1402,30 @@ class ConditionTypeDef(_RequiredConditionTypeDef, _OptionalConditionTypeDef):
 
 
 CreateBackupOutputTypeDef = TypedDict(
-    "CreateBackupOutputTypeDef", {"BackupDetails": "BackupDetailsTypeDef"}, total=False
+    "CreateBackupOutputTypeDef",
+    {"BackupDetails": "BackupDetailsTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 CreateGlobalTableOutputTypeDef = TypedDict(
     "CreateGlobalTableOutputTypeDef",
-    {"GlobalTableDescription": "GlobalTableDescriptionTypeDef"},
+    {
+        "GlobalTableDescription": "GlobalTableDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 CreateTableOutputTypeDef = TypedDict(
-    "CreateTableOutputTypeDef", {"TableDescription": "TableDescriptionTypeDef"}, total=False
+    "CreateTableOutputTypeDef",
+    {"TableDescription": "TableDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 DeleteBackupOutputTypeDef = TypedDict(
-    "DeleteBackupOutputTypeDef", {"BackupDescription": "BackupDescriptionTypeDef"}, total=False
+    "DeleteBackupOutputTypeDef",
+    {"BackupDescription": "BackupDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 DeleteItemOutputTypeDef = TypedDict(
@@ -1425,21 +1452,29 @@ DeleteItemOutputTypeDef = TypedDict(
         ],
         "ConsumedCapacity": "ConsumedCapacityTypeDef",
         "ItemCollectionMetrics": "ItemCollectionMetricsTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
 
 DeleteTableOutputTypeDef = TypedDict(
-    "DeleteTableOutputTypeDef", {"TableDescription": "TableDescriptionTypeDef"}, total=False
+    "DeleteTableOutputTypeDef",
+    {"TableDescription": "TableDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 DescribeBackupOutputTypeDef = TypedDict(
-    "DescribeBackupOutputTypeDef", {"BackupDescription": "BackupDescriptionTypeDef"}, total=False
+    "DescribeBackupOutputTypeDef",
+    {"BackupDescription": "BackupDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 DescribeContinuousBackupsOutputTypeDef = TypedDict(
     "DescribeContinuousBackupsOutputTypeDef",
-    {"ContinuousBackupsDescription": "ContinuousBackupsDescriptionTypeDef"},
+    {
+        "ContinuousBackupsDescription": "ContinuousBackupsDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -1454,6 +1489,7 @@ DescribeContributorInsightsOutputTypeDef = TypedDict(
         ],
         "LastUpdateDateTime": datetime,
         "FailureException": "FailureExceptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1464,13 +1500,20 @@ DescribeEndpointsResponseTypeDef = TypedDict(
 
 DescribeGlobalTableOutputTypeDef = TypedDict(
     "DescribeGlobalTableOutputTypeDef",
-    {"GlobalTableDescription": "GlobalTableDescriptionTypeDef"},
+    {
+        "GlobalTableDescription": "GlobalTableDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 DescribeGlobalTableSettingsOutputTypeDef = TypedDict(
     "DescribeGlobalTableSettingsOutputTypeDef",
-    {"GlobalTableName": str, "ReplicaSettings": List["ReplicaSettingsDescriptionTypeDef"]},
+    {
+        "GlobalTableName": str,
+        "ReplicaSettings": List["ReplicaSettingsDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -1481,23 +1524,32 @@ DescribeLimitsOutputTypeDef = TypedDict(
         "AccountMaxWriteCapacityUnits": int,
         "TableMaxReadCapacityUnits": int,
         "TableMaxWriteCapacityUnits": int,
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
 
 DescribeTableOutputTypeDef = TypedDict(
-    "DescribeTableOutputTypeDef", {"Table": "TableDescriptionTypeDef"}, total=False
+    "DescribeTableOutputTypeDef",
+    {"Table": "TableDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 DescribeTableReplicaAutoScalingOutputTypeDef = TypedDict(
     "DescribeTableReplicaAutoScalingOutputTypeDef",
-    {"TableAutoScalingDescription": "TableAutoScalingDescriptionTypeDef"},
+    {
+        "TableAutoScalingDescription": "TableAutoScalingDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 DescribeTimeToLiveOutputTypeDef = TypedDict(
     "DescribeTimeToLiveOutputTypeDef",
-    {"TimeToLiveDescription": "TimeToLiveDescriptionTypeDef"},
+    {
+        "TimeToLiveDescription": "TimeToLiveDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -1581,6 +1633,7 @@ GetItemOutputTypeDef = TypedDict(
             ],
         ],
         "ConsumedCapacity": "ConsumedCapacityTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1647,28 +1700,48 @@ class GlobalTableGlobalSecondaryIndexSettingsUpdateTypeDef(
 
 ListBackupsOutputTypeDef = TypedDict(
     "ListBackupsOutputTypeDef",
-    {"BackupSummaries": List["BackupSummaryTypeDef"], "LastEvaluatedBackupArn": str},
+    {
+        "BackupSummaries": List["BackupSummaryTypeDef"],
+        "LastEvaluatedBackupArn": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 ListContributorInsightsOutputTypeDef = TypedDict(
     "ListContributorInsightsOutputTypeDef",
-    {"ContributorInsightsSummaries": List["ContributorInsightsSummaryTypeDef"], "NextToken": str},
+    {
+        "ContributorInsightsSummaries": List["ContributorInsightsSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 ListGlobalTablesOutputTypeDef = TypedDict(
     "ListGlobalTablesOutputTypeDef",
-    {"GlobalTables": List["GlobalTableTypeDef"], "LastEvaluatedGlobalTableName": str},
+    {
+        "GlobalTables": List["GlobalTableTypeDef"],
+        "LastEvaluatedGlobalTableName": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 ListTablesOutputTypeDef = TypedDict(
-    "ListTablesOutputTypeDef", {"TableNames": List[str], "LastEvaluatedTableName": str}, total=False
+    "ListTablesOutputTypeDef",
+    {
+        "TableNames": List[str],
+        "LastEvaluatedTableName": str,
+        "ResponseMetadata": "ResponseMetadata",
+    },
+    total=False,
 )
 
 ListTagsOfResourceOutputTypeDef = TypedDict(
-    "ListTagsOfResourceOutputTypeDef", {"Tags": List["TagTypeDef"], "NextToken": str}, total=False
+    "ListTagsOfResourceOutputTypeDef",
+    {"Tags": List["TagTypeDef"], "NextToken": str, "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 LocalSecondaryIndexTypeDef = TypedDict(
@@ -1712,6 +1785,7 @@ PutItemOutputTypeDef = TypedDict(
         ],
         "ConsumedCapacity": "ConsumedCapacityTypeDef",
         "ItemCollectionMetrics": "ItemCollectionMetricsTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1762,6 +1836,7 @@ QueryOutputTypeDef = TypedDict(
             ],
         ],
         "ConsumedCapacity": "ConsumedCapacityTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1827,13 +1902,13 @@ ReplicationGroupUpdateTypeDef = TypedDict(
 
 RestoreTableFromBackupOutputTypeDef = TypedDict(
     "RestoreTableFromBackupOutputTypeDef",
-    {"TableDescription": "TableDescriptionTypeDef"},
+    {"TableDescription": "TableDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
 RestoreTableToPointInTimeOutputTypeDef = TypedDict(
     "RestoreTableToPointInTimeOutputTypeDef",
-    {"TableDescription": "TableDescriptionTypeDef"},
+    {"TableDescription": "TableDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
@@ -1889,6 +1964,7 @@ ScanOutputTypeDef = TypedDict(
             ],
         ],
         "ConsumedCapacity": "ConsumedCapacityTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -1897,7 +1973,11 @@ TransactGetItemTypeDef = TypedDict("TransactGetItemTypeDef", {"Get": "GetTypeDef
 
 TransactGetItemsOutputTypeDef = TypedDict(
     "TransactGetItemsOutputTypeDef",
-    {"ConsumedCapacity": List["ConsumedCapacityTypeDef"], "Responses": List["ItemResponseTypeDef"]},
+    {
+        "ConsumedCapacity": List["ConsumedCapacityTypeDef"],
+        "Responses": List["ItemResponseTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -1917,13 +1997,17 @@ TransactWriteItemsOutputTypeDef = TypedDict(
     {
         "ConsumedCapacity": List["ConsumedCapacityTypeDef"],
         "ItemCollectionMetrics": Dict[str, List["ItemCollectionMetricsTypeDef"]],
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
 
 UpdateContinuousBackupsOutputTypeDef = TypedDict(
     "UpdateContinuousBackupsOutputTypeDef",
-    {"ContinuousBackupsDescription": "ContinuousBackupsDescriptionTypeDef"},
+    {
+        "ContinuousBackupsDescription": "ContinuousBackupsDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -1935,19 +2019,27 @@ UpdateContributorInsightsOutputTypeDef = TypedDict(
         "ContributorInsightsStatus": Literal[
             "ENABLING", "ENABLED", "DISABLING", "DISABLED", "FAILED"
         ],
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
 
 UpdateGlobalTableOutputTypeDef = TypedDict(
     "UpdateGlobalTableOutputTypeDef",
-    {"GlobalTableDescription": "GlobalTableDescriptionTypeDef"},
+    {
+        "GlobalTableDescription": "GlobalTableDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 UpdateGlobalTableSettingsOutputTypeDef = TypedDict(
     "UpdateGlobalTableSettingsOutputTypeDef",
-    {"GlobalTableName": str, "ReplicaSettings": List["ReplicaSettingsDescriptionTypeDef"]},
+    {
+        "GlobalTableName": str,
+        "ReplicaSettings": List["ReplicaSettingsDescriptionTypeDef"],
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
@@ -1975,23 +2067,32 @@ UpdateItemOutputTypeDef = TypedDict(
         ],
         "ConsumedCapacity": "ConsumedCapacityTypeDef",
         "ItemCollectionMetrics": "ItemCollectionMetricsTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
 
 UpdateTableOutputTypeDef = TypedDict(
-    "UpdateTableOutputTypeDef", {"TableDescription": "TableDescriptionTypeDef"}, total=False
+    "UpdateTableOutputTypeDef",
+    {"TableDescription": "TableDescriptionTypeDef", "ResponseMetadata": "ResponseMetadata"},
+    total=False,
 )
 
 UpdateTableReplicaAutoScalingOutputTypeDef = TypedDict(
     "UpdateTableReplicaAutoScalingOutputTypeDef",
-    {"TableAutoScalingDescription": "TableAutoScalingDescriptionTypeDef"},
+    {
+        "TableAutoScalingDescription": "TableAutoScalingDescriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
 UpdateTimeToLiveOutputTypeDef = TypedDict(
     "UpdateTimeToLiveOutputTypeDef",
-    {"TimeToLiveSpecification": "TimeToLiveSpecificationTypeDef"},
+    {
+        "TimeToLiveSpecification": "TimeToLiveSpecificationTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
+    },
     total=False,
 )
 
